==> alg-common-1.19.7-20190827.095037-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/SelectPoolInfo.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;

/**
 * @author lijingzhe
 * @description 优选bean
 * @date 2019/8/22
 */
public class SelectPoolInfo {
    private double reward;
    private long activityType;
    private int index;
    private long activityId;
    private double changeScore;
    private double hrpm;
    private double arpm;
    private double grpm;
    private double request;
    private boolean excellent;
    private double scores;

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public int getIndex() {
        return index;
    }

    public void setIndex(int index) {
        this.index = index;
    }

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public double getHrpm() {
        return hrpm;
    }

    public void setHrpm(double hrpm) {
        this.hrpm = hrpm;
    }

    public double getArpm() {
        return arpm;
    }

    public void setArpm(double arpm) {
        this.arpm = arpm;
    }

    public double getGrpm() {
        return grpm;
    }

    public void setGrpm(double grpm) {
        this.grpm = grpm;
    }

    public double getRequest() {
        return request;
    }

    public void setRequest(double request) {
        this.request = request;
    }

    public boolean isExcellent() {
        return excellent;
    }

    public void setExcellent(boolean excellent) {
        this.excellent = excellent;
    }

    public double getScores() {
        return scores;
    }

    public void setScores(double scores) {
        this.scores = scores;
    }
}

==> alg-common-1.22.1-20191009.085457-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/SelectPoolInfo.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;

/**
 * @author lijingzhe
 * @description 优选bean
 * @date 2019/8/22
 */
public class SelectPoolInfo {
    private double reward;
    private long activityType;
    private int index;
    private long activityId;
    private double changeScore;
    private double hrpm;
    private double arpm;
    private double grpm;
    private double request;
    private int subType;
    private boolean excellent;
    private double scores;

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public int getIndex() {
        return index;
    }

    public void setIndex(int index) {
        this.index = index;
    }

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public double getHrpm() {
        return hrpm;
    }

    public void setHrpm(double hrpm) {
        this.hrpm = hrpm;
    }

    public double getArpm() {
        return arpm;
    }

    public void setArpm(double arpm) {
        this.arpm = arpm;
    }

    public double getGrpm() {
        return grpm;
    }

    public void setGrpm(double grpm) {
        this.grpm = grpm;
    }

    public double getRequest() {
        return request;
    }

    public void setRequest(double request) {
        this.request = request;
    }

    public boolean isExcellent() {
        return excellent;
    }

    public void setExcellent(boolean excellent) {
        this.excellent = excellent;
    }

    public double getScores() {
        return scores;
    }

    public void setScores(double scores) {
        this.scores = scores;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }
}
